@@ -1264,7 +1264,7 @@ class Submission(Base):
 
                     # Distribute dirs over num_dir_slots:
                     for k in range(0, max_num_tasks, step_size[cg_sub_idx]):
-                        dir_idx = floor((k / max_num_tasks) * num_dir_vals)
+                        dir_idx = round((k / max_num_tasks) * num_dir_vals)
                         all_dir_slots[k] = 'REPLACE_WITH_DIR_{}'.format(dir_idx)
 
                     wk_dirs_path = iter_path.joinpath('working_dirs_{}{}'.format(
@@ -1279,7 +1279,7 @@ class Submission(Base):
                 var_values_path = sg_path.joinpath('var_values')
                 var_values_path.mkdir()
                 for j in range(1, max_num_tasks + 1):
-                    j_fmt = zeropad(j, max_num_tasks + 1)
+                    j_fmt = zeropad(j, max_num_tasks)
                     vv_j_path = var_values_path.joinpath(j_fmt)
                     vv_j_path.mkdir()
 
@@ -1605,7 +1605,13 @@ class CommandGroupSubmission(Base):
         blocked = True
         while blocked:
 
-            session.refresh(self)
+            try:
+                session.refresh(self)
+            except OperationalError:
+                # Database is likely locked.
+                print(block_msg.format(datetime.now()), flush=True)
+                sleep(sleep_time)
+                continue
 
             if self.is_command_writing:
                 print(block_msg.format(datetime.now()), flush=True)
